@@ -1,7 +1,7 @@
 #!/bin/sh
-V=4.0.7
+V=4.1.1
 prefix=/usr
-infodir=${prefix}/info
+infodir=${prefix}/share/info
 
 # Install the .info files
 cd ${infodir}
